@@ -25,7 +25,7 @@ from urllib3.util.retry import Retry
 from .._utils._constants import WORK_ORDER_STATUS, WORK_ORDER_CATEGORY, WORK_ORDER_PRIORITY
 
 __all__ = ['generate_password', 'convert_to_sqm', 'convert_to_pascal_case', 'ValidatedSetterProperty', 'ApiInputs',
-           'DiscoveryIntegrationInput', 'DataFeedFileProcessOutput', 'requests_retry_session', 'is_valid_uuid']
+           'DiscoveryIntegrationInput', 'DataFeedFileProcessOutput', 'requests_retry_session', 'is_valid_uuid', 'convert_bytes']
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -269,6 +269,19 @@ def is_valid_uuid(uuid_to_test: Union[uuid.UUID, str], version=4) -> bool:
         return False
     return str(uuid_obj) == uuid_to_test
 
+def convert_bytes(bytes_number):
+    tags = [ "Byte", "Kilobyte", "Megabyte", "Gigabyte", "Terabyte" ]
+ 
+    i = 0
+    double_bytes = bytes_number
+ 
+    while (i < len(tags) and  bytes_number >= 1024):
+            double_bytes = bytes_number / 1024.0
+            i = i + 1
+            bytes_number = bytes_number / 1024
+ 
+    return str(round(double_bytes, 2)) + " " + tags[i]
+
 _site_schema = pandera.DataFrameSchema(
     {
         'InstallationName': pandera.Column(pandera.String, checks=pandera.Check.str_length(1, 255)),
