@@ -6,6 +6,7 @@
 """
 A module for integrating asset creation, asset updates, data ingestion, etc into the Switch Automation Platform.
 """
+import gc
 import re
 import sys
 import pandas
@@ -16,8 +17,7 @@ import datetime
 import logging
 import uuid
 from .._utils._platform import _get_structure, Blob
-from .._utils._utils import (ApiInputs, _with_func_attrs, _column_name_cap, _work_order_schema,
-                             DiscoveryIntegrationInput, convert_to_pascal_case)
+from .._utils._utils import (ApiInputs, _with_func_attrs, _column_name_cap, _work_order_schema, convert_bytes)
 from .._utils._constants import TAG_LEVEL
 from ..integration._utils import _timezone_offsets, _upsert_entities_affected_count, _adx_support, _timezone_dst_offsets
 
@@ -889,6 +889,7 @@ def upsert_timeseries(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_time
     """
 
     data_frame = df.copy()
+    logger.info(f'Data frame size: {convert_bytes(data_frame.memory_usage(deep=True).sum())}')
 
     if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
@@ -909,6 +910,7 @@ def upsert_timeseries(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_time
             j_row = row[list(slice_columns)].to_json()
             return str(j_row)
 
+        logger.info('Creating Meta Column.')
         data_frame['Meta'] = data_frame[list(slice_columns)].assign(
             **data_frame[list(slice_columns)].select_dtypes(['datetime', 'object']).astype(str)).apply(update_values, axis=1)
 
@@ -967,10 +969,16 @@ def upsert_timeseries(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_time
             return row
 
         timezones_df = timezones_df.apply(convert_dst_interval_range_to_utc, axis=1)
-        timezones_df = timezones_df.drop(columns=['timezoneId', 'timezoneName', 'standardOffsetUtc', 'dstOffsetUtc'])
+    timezones_df = timezones_df.drop(columns=['timezoneId', 'standardOffsetUtc', 'dstOffsetUtc'])
 
+    logger.info('Merging data frame input with timezone installation dst offsets.')
     data_frame = data_frame.merge(timezones_df, left_on='InstallationId', right_on='installationId', how='inner')
+
+    del timezones_df
+    gc.collect()
+
     data_frame = data_frame[(data_frame.Timestamp >= data_frame.start) & (data_frame.Timestamp <= data_frame.end) & (data_frame.Timestamp.apply(lambda x: x.year) == data_frame.year)]
+    data_frame = data_frame.drop(columns=['start', 'end', 'year'])
 
     if is_local_time:
         def to_utc(row):
@@ -1006,28 +1014,27 @@ def upsert_timeseries(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_time
             j_row = row[date_col].replace(minute=45)
             return j_row
 
-    def convert_to_iso_format_string(row):
-        timestamp_format = "%Y-%m-%dT%H:%M:%SZ"
-        row['Timestamp'] = row['Timestamp'].to_pydatetime().replace(second=0, microsecond=0).strftime(timestamp_format)
-        row['TimestampLocal'] = row['TimestampLocal'].to_pydatetime().replace(second=0, microsecond=0).strftime(timestamp_format)
-        row['TimestampId'] = row['TimestampId'].to_pydatetime().replace(second=0, microsecond=0).strftime(timestamp_format)
-        row['TimestampLocalId'] = row['TimestampLocalId'].to_pydatetime().replace(second=0, microsecond=0).strftime(timestamp_format)
-        return row
-
+    logger.info('Date time conversion and formatting.')
     data_frame['TimestampId'] = data_frame.apply(bin_to_15_minute_interval, args=('Timestamp',), axis=1)
     data_frame['TimestampLocalId'] = data_frame.apply(bin_to_15_minute_interval, args=('TimestampLocal',), axis=1)
-    data_frame = data_frame.apply(convert_to_iso_format_string, axis=1)
+
+    timestamp_format = "%Y-%m-%dT%H:%M:%SZ"
+    data_frame['Timestamp'] = data_frame['Timestamp'].dt.strftime(timestamp_format)
+    data_frame['TimestampLocal'] = data_frame['TimestampLocal'].dt.strftime(timestamp_format)
+    data_frame['TimestampId'] = data_frame['TimestampId'].dt.strftime(timestamp_format)
+    data_frame['TimestampLocalId'] = data_frame['TimestampLocalId'].dt.strftime(timestamp_format)
 
     headers = api_inputs.api_headers.integration
 
     logger.info("Upserting data to Timeseries.")
-
     data_frame = data_frame.loc[:, ['ObjectPropertyId', 'Timestamp', 'TimestampId', 'TimestampLocal',
                                     'TimestampLocalId', 'Value', 'DataFeedFileStatusId', 'InstallationId', 'Meta']]
 
     container = 'data-ingestion-timeseries-adx'
     folder = 'to-eventhub'
     name = 'Timeseries'
+    
+    logger.info(f'Data frame size: {convert_bytes(data_frame.memory_usage(deep=True).sum())}')
 
     upload_result = Blob.upload(api_inputs=api_inputs, data_frame=data_frame, container=container, folder=folder, name=name, batch_id=data_feed_file_status_id, include_header=True)
 
